BankAlfalahConfig class

Configuration for Bank Alfalah payment gateway.

Contains all the necessary credentials and settings required to initialize and process payments through Bank Alfalah's payment gateway.

Constructors

BankAlfalahConfig({required String merchantId, required String merchantPassword, required String merchantUsername, required String merchantHash, required String storeId, required String returnUrl, required String firstKey, required String secondKey, String channelId = '1001', bool debugMode = false})
Creates a new configuration for Bank Alfalah payment gateway.

Properties

channelId String
Channel ID provided by Bank Alfalah (default: '1001')
final
debugMode bool
Flag to enable debug mode
final
firstKey String
First key for hash generation
final
hashCode int
The hash code for this object.
no setterinherited
merchantHash String
Merchant hash key provided by Bank Alfalah
final
merchantId String
Merchant ID provided by Bank Alfalah
final
merchantPassword String
Merchant password provided by Bank Alfalah
final
merchantUsername String
Merchant username provided by Bank Alfalah
final
returnUrl String
Return URL to which the payment gateway will redirect after payment
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondKey String
Second key for hash generation
final
storeId String
Store ID provided by Bank Alfalah
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited