PaymentRequest class

Constructors

PaymentRequest({required String amount, String? orderId, String? customerName, String? customerEmail, String? customerPhone, Map<String, dynamic>? additionalData})

Properties

additionalData Map<String, dynamic>?
Any additional data to be passed (optional)
final
amount String
Amount to be charged
final
customerEmail String?
Customer email (optional)
final
customerName String?
Customer name (optional)
final
customerPhone String?
Customer phone (optional)
final
hashCode int
The hash code for this object.
no setterinherited
orderId String?
Order ID or any unique identifier for this transaction
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited