PaymentResponse class
Constructors
-
PaymentResponse({required bool success, String? responseCode, String? transactionReferenceNumber, String? message, Map<
String, dynamic> ? responseData}) - PaymentResponse.error(String message)
-
factory
-
PaymentResponse.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
Response message
final
- responseCode → String?
-
Response code from Bank Alfalah
final
-
responseData
→ Map<
String, dynamic> ? -
Raw response data
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether the payment was successful
final
- transactionReferenceNumber → String?
-
Transaction reference number
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited