PaymentResult class
Constructors
- PaymentResult({required PaymentStatus status, PaymentResponse? response, String? errorMessage})
- PaymentResult.cancelled()
-
factory
- PaymentResult.error(String message)
-
factory
- PaymentResult.failed(PaymentResponse response)
-
factory
- PaymentResult.success(PaymentResponse response)
-
factory
Properties
- errorMessage → String?
-
Error message if any
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
no setter
- response → PaymentResponse?
-
Response from Bank Alfalah
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → PaymentStatus
-
Status of the payment
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited